# pytools

Collection of helper tools

## Installation

Run the following to install:
```python
pip install toolsjps
```

# Developing
To install the package along with the tools you need to develop and run the tests,
run the following in your virtualenv:

```bash
$ pip install -e .[dev]
```